<?php
namespace Teknisa\SUP\Modules\Cotacao\Modules\ListaPreco\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use \Setforms2\Shared\ORM\DateTime;
use Exception;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class Sup01200MontagemListaPrecoController extends \Teknisa\GER\Controllers\TeknisaCrud {
    
    protected $crudService;
    protected $service;
    protected $connection;
    protected $newCode;
    
    public function __construct($crudService, $parameterBag, $connection, $environment, $newCode, $service) {
        $this->crudService  = $crudService;
        $this->connection   = $connection;
        $this->environment  = $environment;
        $this->newCode      = $newCode;
        $this->service      = $service;
    }
    
    public function validaComprador(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
          
            $op = $this->crudService->getFilteredDataSet("comproper_comprador", $conditions)->getRows();
           
            $dataset = [];
               
                    if($op[0]["IDEXSENHCMPOPER"] == "S")
                        $dataset["EXIGE_SENHA"] = true;
                    $response->addDataSet(new DataSet('dados', $dataset));
                }
             catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function confirmaSenhaComprador(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $resultado = [];
            $senha = $this->service->senhaOperador($row["CDCOMPRADOR"]);
         
            if($senha && md5($row["SENHA"]) != $senha)
                throw new Exception("Senha inválida!");
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    public function validaData(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows();
            $dados = $this->service->validaData($row);
            $response->addDataSet(new DataSet('dados', $dados));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function montarLista(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $data = array();
        //$cdfilial = $this->environment->getCdFilial();
        $cdfilial = $row['P_CDFILIAL'];
        $tabela = "PREVLISTA";
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $row['P_CDOPERADOR'];
        $res = $this->service->verificaCentral($cdfilial);
        if (!empty($res)) {
            $central = $res[0]['CDFILCENTCMP'];
            $p_contador = $tabela . $central;
        }
        else {
            $p_contador = $tabela . $cdfilial;
        }
        //$result = $this->service->selectFilialNrcolepreco($row);

        $novo_codigo = $this->newCode->getCodeByTableName($p_contador, $this->environment->getNrorgTrab(), 1, 10, false);
        $regiao = $row["P_REGIAO"];
        
        $tregiao = "";
        
        $result = $this->service->selectCdfilial(array("CDFILIAL" => $cdfilial, "NOVOCOD" => $novo_codigo));
        
        if($row['P_CARREGACOT'] == 'T'){
            $carregacot = "S";
        } else {
            $carregacot = "N";
        }
        if (empty($result)){
            $this->service->insertPrevlista($cdfilial, $novo_codigo, $regiao, $cdoperador, $row, $carregacot);
        } else {
            $this->service->updatePrevLista($cdfilial, $novo_codigo);
        }
        if($regiao == 'T') {
            $regioes = $this->service->selectCdregiao(array( "P_CDREGIAO" => null, "P_TCDREGIAO" => "T"));
            $regiao = join('_', $regioes[0]);
            $tregiao = 'todas';
        } else {
            $regioes = explode('_', $regiao);
        }
        $coincideData = ($row["P_COINCIDE"] != "N");
        foreach ($regioes as $reg) {
            if($tregiao == 'todas') {
                $regiao = $reg['CDREGIAO'];
            }else{
                $regiao = $reg;
            }
           $this->service->insertItmprevlist($cdfilial, $novo_codigo, $cdoperador, $regiao, $row, $coincideData);
        }
        $this->service->deleteItmprevlistNotExists($cdfilial, $novo_codigo);
        $result = $this->service->selectContadorItmprevlist($cdfilial, $novo_codigo);
        if($result[0]['CONTADOR'] == 0){
            $this->service->updateItemcole($cdfilial, $novo_codigo);
            $this->service->deletePrevlist($cdfilial, $novo_codigo);
        }
        //if (((is_array($result[0]['CONTADOR']) && !is_null($result[0]['CONTADOR'])) ? count($result[0]['CONTADOR']) : 0) < 2) {}
        
        $data["NOVOCOD"] = $novo_codigo;
        $response->addDataSet(new DataSet('data', $data));
    }
    
    public function buscarObservacao(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $data = array();
        $query = "SELECT DSPREVLIST, NRORG FROM PREVLISTA WHERE PREVLISTA.CDFILIAL = :P_CDFILIAL AND PREVLISTA.NRSEQPRELIST = :P_NRSEQPRELIST";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILIAL" => $row["P_CDFILIAL"],
            "P_NRSEQPRELIST" => $row["P_NRSEQPRELIST"]
        ));
        $result = $stmt->fetchAll();
      
        $data['DSPREVLIST'] = $result[0]["DSPREVLIST"];
        $response->addDataSet(new DataSet('data', $data));
    }
    
    public function salvarObservacao(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        if (strlen($row['P_DSPREVLIST']) > 50) {
            $response->setError(new Error("Mensagem acima do tamanho máximo permitido (50 caracteres).", 0));
        } else {
            $query = "UPDATE PREVLISTA SET DSPREVLIST = :P_DSPREVLIST WHERE CDFILIAL = :P_CDFILIAL AND NRSEQPRELIST = :P_NRSEQPRELIST";
            $stmt = $this->connection->prepare($query);
            $stmt->execute(array(
                "P_DSPREVLIST" => $row['P_DSPREVLIST'],
                "P_CDFILIAL" => $row["P_CDFILIAL"],
                "P_NRSEQPRELIST" => $row["P_NRSEQPRELIST"]
            ));
        }
    }
    
    public function acmDeleteItemsPrev ($P_CDFILIAL, $P_NRSEQPRELIST){
        $query = "DELETE ITMPREVLIST WHERE IDITMSELLIS = 'N' AND CDFILIAL = :P_CDFILIAL AND NRSEQPRELIST = :P_NRSEQPRELIST";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILIAL" => $P_CDFILIAL,
            "P_NRSEQPRELIST" => $P_NRSEQPRELIST
        ));
    }
    
    public function adqLock ($P_CDFILIAL, $P_DTINIVALITM, $P_DTFINVALITM, $P_CDREGIAO, $P_TCDREGIAO, $P_CDPRODINI, $P_CDPRODFIN, $P_TPRODUTO, $P_CDOPERADOR){
        $query = "SELECT CDOPERADOR, NRSEQLOCKLIST FROM LOCK_LISTA WHERE CDFILIAL = :P_CDFILIAL AND((DTINIVALITMLOCK <= :P_DTINIVALITM AND DTFINVALITMLOCK >= :P_DTFINVALITM) OR (DTINIVALITMLOCK >= :P_DTINIVALITM AND DTFINVALITMLOCK <= :P_DTFINVALITM)) AND ((INSTR(DSREGIAOLOCK, :P_CDREGIAO) > 0) OR (INSTR(:P_CDREGIAO, DSREGIAOLOCK) > 0) OR (:P_TCDREGIAO = 'T') OR (IDTCDREGIAOLOCK = 'T') ) AND ((CDPRODINILOCK >= :P_CDPRODINI AND CDPRODFINLOCK <= :P_CDPRODFIN) OR (CDPRODINILOCK <= :P_CDPRODINI AND CDPRODFINLOCK >= :P_CDPRODFIN) OR (:P_TPRODUTO = 'T') OR (IDTPRODUTOLOCK = 'T') ) AND CDCOMPRADOR = :P_CDOPERADOR";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILIAL" => $P_CDFILIAL,
            "P_DTINIVALITM" => $P_DTINIVALITM,
            "P_DTFINVALITM" => $P_DTFINVALITM,
            "P_CDREGIAO" => $P_CDREGIAO,
            "P_TCDREGIAO" => $P_TCDREGIAO,
            "P_CDPRODINI" => $P_CDPRODINI,
            "P_CDPRODFIN" => $P_CDPRODFIN,
            "P_TPRODUTO" => $P_TPRODUTO,
            "P_CDOPERADOR" => $P_CDOPERADOR
        ));
        return $stmt->fetchAll();
    }
    
    public function acmLock ($P_PRXLOCK, $P_CDFILIAL, $P_DTINIVALITM, $P_DTFINVALITM, $P_CDREGIAO, $P_TCDREGIAO, $P_CDPRODINI, $P_CDPRODFIN, $P_TPRODUTO, $P_CDCOMPRADOR, $P_CDOPERADOR){
        $query = "INSERT INTO LOCK_LISTA( NRSEQLOCKLIST, CDFILIAL, DTINIVALITMLOCK, DTFINVALITMLOCK, DSREGIAOLOCK, IDTCDREGIAOLOCK, CDPRODINILOCK, CDPRODFINLOCK, IDTPRODUTOLOCK, CDCOMPRADOR, CDOPERADOR) VALUES (:P_PRXLOCK,:P_CDFILIAL,:P_DTINIVALITM,:P_DTFINVALITM, :P_CDREGIAO,:P_TCDREGIAO,:P_CDPRODINI,:P_CDPRODFIN, :P_TPRODUTO,:P_CDCOMPRADOR, :P_CDOPERADOR)";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_PRXLOCK" => $P_PRXLOCK,
            "P_CDFILIAL" => $P_CDFILIAL,
            "P_DTINIVALITM" => $P_DTINIVALITM,
            "P_DTFINVALITM" => $P_DTFINVALITM,
            "P_CDREGIAO" => $P_CDREGIAO,
            "P_TCDREGIAO" => $P_TCDREGIAO,
            "P_CDPRODINI" => $P_CDPRODINI,
            "P_CDPRODFIN" => $P_CDPRODFIN,
            "P_TPRODUTO" => $P_TPRODUTO,
            "P_CDCOMPRADOR" => $P_CDCOMPRADOR,
            "P_CDOPERADOR" => $P_CDOPERADOR
        ));
    }
    
    public function adqCountItmPrevList ($P_CDFILIAL, $P_NRSEQPRELIST){
        $query = "SELECT COUNT(*) AS CONTADOR FROM ITMPREVLIST WHERE(NRSEQPRELIST = :P_NRSEQPRELIST) AND (CDFILIAL = :P_CDFILIAL)";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILIAL" => $P_CDFILIAL,
            "P_NRSEQPRELIST" => $P_NRSEQPRELIST
        ));
        $result = $stmt->fetchAll();
        
        return $result[0]["CONTADOR"];
    }
    
    
    public function adsLimpaItens($P_CDFILIAL, $P_DTINIVALITM, $P_DTFINVALITM, $P_CDREGIAO, $P_TCDREGIAO, $P_CDPRODINI, $P_CDPRODFIN, $P_TPRODUTO, $P_CARGCOT, $P_CDOPERADOR, $P_NRSEQPRELIST, $P_PREENCHETAB, $P_COINCIDE){
        $p_coincide = ($P_COINCIDE) ? 'S' : 'N';
                
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'LIMPA_ITEMCOLE_MONTAGEM');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $P_CDFILIAL, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINIVALITM',    Param::PARAM_INPUT, $P_DTINIVALITM, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINVALITM',    Param::PARAM_INPUT, $P_DTFINVALITM, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDREGIAO',    Param::PARAM_INPUT, $P_CDREGIAO, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TCDREGIAO',    Param::PARAM_INPUT, $P_TCDREGIAO, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODINI',    Param::PARAM_INPUT, $P_CDPRODINI, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODFIN',    Param::PARAM_INPUT, $P_CDPRODFIN, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TPRODUTO',    Param::PARAM_INPUT, $P_TPRODUTO, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CARGCOT',    Param::PARAM_INPUT, $P_CARGCOT, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDOPERADOR',    Param::PARAM_INPUT, $P_CDOPERADOR, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQPRELIST',    Param::PARAM_INPUT, $P_NRSEQPRELIST, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PREENCHETAB',    Param::PARAM_INPUT, $P_PREENCHETAB, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_COINCIDE',    Param::PARAM_INPUT, $p_coincide, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ROWSAFFECT',  Param::PARAM_OUTPUT, NULL,         Param::PARAM_TYPE_STR, 20));
        $rowsaffect = $procedure->execute();
        return $rowsaffect["P_ROWSAFFECT"];
    }
    
    public function habilitaMarca($IDAPRMARPRO, $IDAUTMARPRO, $DTVALAPROVA, $DTATUALBD, $IDULTIDTVALQ) {
        if ((($IDAPRMARPRO == 'N') && ($IDAUTMARPRO == 'N')) || (($IDAPRMARPRO == 'S') && ((($IDULTIDTVALQ == 'M') && ($DTATUALBD > $ULTIMODIAMESDTVALAPROVA)) || (($IDULTIDTVALQ == 'D') && ($DTATUALBD > $DTVALAPROVA))))){
            return false;
        } else {
            return true;
        }
    }
    
    public function habilitaFornecedorProduto($IDFORNAPROV, $IDFORNAUTOR, $DTATUALBD, $DTVALPRFORN, $IDULTIDTVALQ) {
        if ((($IDFORNAPROV == 'N') && ($IDFORNAUTOR == 'N')) || (($IDFORNAPROV == 'S') && ((($IDULTIDTVALQ == 'M') && ($DTATUALBD > $ULTIMODIAMESDTVALPRFORN)) || (($IDULTIDTVALQ == 'D') && ($DTATUALBD > $DTVALPRFORN))))){
            return false;
        } else {
            return true;
        }
    }
    
    public function acmUpdateItmPrevList (DTO\Request $request, DTO\Response $response) {
        $rows = $request->getDataSet()->getRows();
        $query = "SELECT IDULTIDTVALQ FROM PARASUPRI WHERE CDFILIAL = :P_CDFILCENT";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILCENT" => $rows[0]["CDFILIALCENTRAL"]
        ));
        $result = $stmt->fetchAll();
        $result[0]["IDULTIDTVALQ"] = "M";
        foreach($rows as $row) {
            if($row["IDSITUCADA"] == 'A' && $row["IDTIPOFORN"] == 'N' && $row["changed_IDITMSELLIS"] == 'N') {
                if(self::habilitaMarca($row["IDAPRMARPRO"], $row["IDAUTMARPRO"], $row["DTVALAPROVA"], $row["DTATUALBD"], $result[0]["IDULTIDTVALQ"])){
                    if(self::habilitaFornecedorProduto($row["IDFORNAPROV"], $row["IDFORNAUTOR"], $row["DTATUALBD"], $row["DTVALPRFORN"], $result[0]["IDULTIDTVALQ"])){
                        if(!empty(self::habilitaFornecedor($row["CDFORNECED"], $result[0]["IDULTIDTVALQ"]))){
                            $query2 = "UPDATE ITMPREVLIST SET IDITMSELLIS = :IDITMSELLIS WHERE CDFILIAL = :CDFILIAL AND NRSEQPRELIST = :NRSEQPRELIST AND NRCOLEPRECO = :NRCOLEPRECO AND CDFORNECED = :CDFORNECED AND CDREGIAO = :CDREGIAO AND CDPRODUTO = :CDPRODUTO AND CDMARCA = :CDMARCA ";
                            $stmt2 = $this->connection->prepare($query2);
                            $stmt2->execute(array(
                                "CDFILIAL" => $row["CDFILIAL"],
                                "NRSEQPRELIST" => $row["NRSEQPRELIST"],
                                "NRCOLEPRECO" => $row["NRCOLEPRECO"],
                                "CDFORNECED" => $row["CDFORNECED"],
                                "CDREGIAO" => $row["CDREGIAO"],
                                "CDPRODUTO" => $row["CDPRODUTO"],
                                "CDMARCA" => $row["CDMARCA"],
                                "IDITMSELLIS" => $row["IDITMSELLIS"]
                            ));
                        }
                    }
                }
            } else if($row["changed_IDITMSELLIS"] == 'S'){
                $query2 = "UPDATE ITMPREVLIST SET IDITMSELLIS = :IDITMSELLIS WHERE CDFILIAL = :CDFILIAL AND NRSEQPRELIST = :NRSEQPRELIST AND NRCOLEPRECO = :NRCOLEPRECO AND CDFORNECED = :CDFORNECED AND CDREGIAO = :CDREGIAO AND CDPRODUTO = :CDPRODUTO AND CDMARCA = :CDMARCA ";
                $stmt2 = $this->connection->prepare($query2);
                $stmt2->execute(array(
                    "CDFILIAL" => $row["CDFILIAL"],
                    "NRSEQPRELIST" => $row["NRSEQPRELIST"],
                    "NRCOLEPRECO" => $row["NRCOLEPRECO"],
                    "CDFORNECED" => $row["CDFORNECED"],
                    "CDREGIAO" => $row["CDREGIAO"],
                    "CDPRODUTO" => $row["CDPRODUTO"],
                    "CDMARCA" => $row["CDMARCA"],
                    "IDITMSELLIS" => $row["IDITMSELLIS"]
                ));
            }
        }
    }
    
    private function strPadRigthProd($value){
	    return str_pad($value, 20, 'Z', STR_PAD_RIGHT);
	}
	
    public function criarLista (DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $oleResult = array();
        switch($row["P_OPCAO"]){
            case 1:
                self::acmDeleteItemsPrev($row["P_CDFILIAL"], $row["P_NRSEQPRELIST"]);
                if($row["P_CDREGIAO"] == ""){
                    $row["P_CDREGIAO"] = null;    
                }
                if($row["P_TCDREGIAO"] == ""){
                    $row["P_TCDREGIAO"] = "T";
                }
                if($row["P_TPRODUTO"] == ""){
                    $row["P_TPRODUTO"] = null;
                }
                if(strlen($row["P_CDPRODFIN"]) < 20){
                    $row["P_CDPRODFIN"] = self::strPadRigthProd($row['P_CDPRODFIN']);
                }
                $adqlock = self::adqLock($row["P_CDFILIAL"], $row["P_DTINIVALITM"], $row["P_DTFINVALITM"], $row["P_CDREGIAO"], $row["P_TCDREGIAO"], $row["P_CDPRODINI"], $row["P_CDPRODFIN"], $row["P_TPRODUTO"], $row["P_CDOPERADOR"]);
                
                if (((is_array($adqlock) && !is_null($adqlock)) ? count($adqlock) : 0) == 0) {
                    $novo_codigo = $this->newCode->getCodeByTableName('LOCKLISTA', $this->environment->getNrorgTrab(), 1, 10, false);
                    self::acmLock($novo_codigo, $row["P_CDFILIAL"], $row["P_DTINIVALITM"], $row["P_DTFINVALITM"], $row["P_CDREGIAO"], $row["P_TCDREGIAO"], $row["P_CDPRODINI"], $row["P_CDPRODFIN"], $row["P_TPRODUTO"], $row["P_CDOPERADOR"], $row["P_CDOPERLANC"]);
                    $oleResult[0] = $novo_codigo;
                }
                else{
                    $oleResult[0] = ($adqlock[0]["CDOPERADOR"]) ? $adqlock[0]["NRSEQLOCKLIST"].$adqlock[0]["CDOPERADOR"] : $adqlock[0]["NRSEQLOCKLIST"].'000000000999';
                }
                $oleResult[1] = self::adqCountItmPrevList($row["P_CDFILIAL"], $row["P_NRSEQPRELIST"]);

                break;
            case 2:
                $connection = $this->connection;
                $procedure = new StoredProcedure($connection, 'CRIA_LISTA');
                $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $row['P_CDFILIAL'], Param::PARAM_TYPE_STR));
                $procedure->addParam(new Param('P_NRSEQPRELIST',    Param::PARAM_INPUT, $row['P_NRSEQPRELIST'], Param::PARAM_TYPE_STR));
	            $procedure->addParam(new Param('P_ROWSAFFECT',  Param::PARAM_OUTPUT, NULL,         Param::PARAM_TYPE_STR, 20));  
                $rowsaffect = $procedure->execute();
                //$oleResult[2] = $rowsaffect["P_ROWSAFFECT"];
                return $rowsaffect["P_ROWSAFFECT"];
                break;    
            case 3:
                $rowsaffect = self::adsLimpaItens($row['P_CDFILIAL'], $row['P_DTINIVALITM'], 
                            $row['P_DTFINVALITM'], $row['P_CDREGIAO'], $row['P_TCDREGIAO'], 
                            $row['P_CDPRODINI'], $row['P_CDPRODFIN'], $row['P_TPRODUTO'], 
                            $row['P_CARGCOT'], $row['P_CDOPERADOR'], $row['P_NRSEQPRELIST'], 'S', $row["P_COINCIDE"]);
                return $rowsaffect;
                //$oleResult[3] = $rowsaffect["P_ROWSAFFECT"];
                break;
            case 4:
                $rowsaffect = self::adsLimpaItens($row['P_CDFILIAL'], $row['P_DTINIVALITM'], 
                            $row['P_DTFINVALITM'], $row['P_CDREGIAO'], $row['P_TCDREGIAO'], 
                            $row['P_CDPRODINI'], $row['P_CDPRODFIN'], $row['P_TPRODUTO'], 
                            $row['P_CARGCOT'], $row['P_CDOPERADOR'], $row['P_NRSEQPRELIST'], 'N', $row["P_COINCIDE"]);
                return $rowsaffect;
                //$oleResult[4] = $rowsaffect["P_ROWSAFFECT"];
                break;
        }
        
        $response->addDataSet(new DataSet('oleResult', $oleResult));
        
    }
    
    public function preparaLista(DTO\Request\Row $request, DTO\Response $response){
        
        $row = $request->getRow();
      
        $query = "UPDATE ITMPREVLIST SET IDITMLISTJAMONT = 'N' WHERE CDFILIAL = :P_CDFILIAL AND NRSEQPRELIST = :P_NRSEQPRELIST AND IDITMLISTJAMONT = 'S'";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILIAL" => $row['P_CDFILIAL'],
            "P_NRSEQPRELIST" => $row['P_NRSEQPRELIST']
        ));
        
    }
    
    public function qryOperador(DTO\Request\Row $request, DTO\Response $response){
        
        $row = $request->getRow();
        
        $query = "SELECT OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR FROM OPERADOR WHERE OPERADOR.CDOPERADOR = :P_CDOPERADOR";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDOPERADOR" => $row['P_CDOPERADOR']
        ));
        $data = $stmt->fetchAll();
        $response->addDataSet(new DataSet('data', $data));

    }
    
    public function gerarListaPrecos(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        $oleResult = $row['oleResult'];
        $stLock = $row['stLock'];
        
        if($row['boConfirma']){
            $pos = 0;
            $row['P_OPCAO'] = 2;
            $inQtdeExistente = $oleResult[1];
            while (($inQtdeExistente - $pos) > 0){
                $reqRow = new DTO\Request\Row($row, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
                $oleResult[2] = self::criarLista($reqRow, $response);
                $pos = $pos + $oleResult[2];
                //$oleResult = $response['oleResult'];
            }
            $row['P_OPCAO'] = 3;
            $reqRow = new DTO\Request\Row($row, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
            $oleResult[3] = self::criarLista($reqRow, $response);
            //$oleResult = $response['oleResult'];
            $pos = 0;
            $row['P_OPCAO'] = 4;
            while(($oleResult[3] - $pos) > 0){
                $reqRow = new DTO\Request\Row($row, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
                $oleResult[4] = self::criarLista($reqRow, $response);
                //$oleResult = $response['oleResult'];
                $pos = $pos + $oleResult[4];
            }
            
            self::finalizaLista($row['P_CDFILIAL'], $row['P_NRSEQPRELIST'], $stLock);
            
        }
        
    }
    
    public function finalizaLista($P_CDFILIAL, $P_NRSEQPRELIST, $P_NRLOCK){
        try{
            $query = "UPDATE PREVLISTA SET IDDISPLISFIL = 'N' WHERE CDFILIAL = :P_CDFILIAL AND NRSEQPRELIST = :P_NRSEQPRELIST";
            $stmt = $this->connection->prepare($query);
            $stmt->execute(array(
                "P_CDFILIAL" => $P_CDFILIAL,
                "P_NRSEQPRELIST" => $P_NRSEQPRELIST
            ));
            
            $query = "UPDATE ITMPREVLIST SET IDITMLISTJAMONT = 'N' WHERE CDFILIAL = :P_CDFILIAL AND NRSEQPRELIST = :P_NRSEQPRELIST ";
            $stmt = $this->connection->prepare($query);
            $stmt->execute(array(
                "P_CDFILIAL" => $P_CDFILIAL,
                "P_NRSEQPRELIST" => $P_NRSEQPRELIST
            ));
            
            if ($P_NRLOCK){
                $query = "DELETE FROM LOCK_LISTA WHERE NRSEQLOCKLIST = :P_PRXLOCK";
                $stmt = $this->connection->prepare($query);
                $stmt->execute(array(
                    "P_PRXLOCK" => $P_NRLOCK
                ));
            }
            
        } catch(Exception $e){
            throw $e;
        }
    }
    
    public function selecCotAuto(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'APURA_LISTA');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $row['P_CDFILIAL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQPRELIST',    Param::PARAM_INPUT, $row['P_NRSEQPRELIST'], Param::PARAM_TYPE_STR));
        $rowsaffect = $procedure->execute();
    }
    
    public function selectParasupri(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $query = "SELECT CDFILIAL , IDJUSSOLEXT , IDBLOQALTNEC, IDAUDALTSOL, IDULTIDTULTI, IDULTCOMPSOL, IDULTDESTSOL, CDGRUPOPER , IDULTIDTVALQ, IDVALDTAF , IDBLOQUEAAF , IDMARSEMQUA, IDTIPOAPUR, IDUTLPROCMP, NRCOTESCAUTO, IDVISCOTPLA, IDUMPRODCMP, CDMARCA, IDPROSEMMAR, CDGRUPPROD, DSDIRLOGAUTF, IDUTSTATUSLISPR FROM PARASUPRI WHERE CDFILIAL = :P_CDFILCENT";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILCENT" => $row["CDFILCENTCMP"]
        ));
        $result = $stmt->fetchAll();
        $response->addDataSet(new DataSet('data', $result));
    }
    
    public function habilitaFornecedor($CDFORNECED, $IDULTIDTVALQ) {
        $query = "SELECT FORNECEDOR.CDFORNECED FROM FORNECEDOR, QUALIFICACAO WHERE FORNECEDOR.CDFORNECED = :P_CDFORNECED AND (FORNECEDOR.CDQUALIF IS NOT NULL AND FORNECEDOR.CDQUALIF = QUALIFICACAO.CDQUALIF AND ((QUALIFICACAO.IDPERCOTCMP = '1') OR (QUALIFICACAO.IDPERCOTCMP = '2' AND FORNECEDOR.IDFORNAUTO = 'S')) AND((:P_IDULTIDTVALQ = 'D' AND TO_DATE(SYSDATE) <= FORNECEDOR.DTVALQUALIF) OR (:P_IDULTIDTVALQ = 'M' AND TO_DATE(SYSDATE) <= LAST_DAY(FORNECEDOR.DTVALQUALIF)))) UNION SELECT FORNECEDOR.CDFORNECED FROM FORNECEDOR WHERE FORNECEDOR.CDFORNECED = :P_CDFORNECED AND FORNECEDOR.CDQUALIF IS NULL";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFORNECED" => $CDFORNECED,
            "P_IDULTIDTVALQ" => $IDULTIDTVALQ
        ));
        return $result = $stmt->fetchAll();
    }
}